## header.h

    path /Users/jacob.repp/dev/cxmeta/test/simple-module/header.h

### cxm_page_header


 # Some header

 

 This is the top of the header


~~~c



~~~

### cxm_function


 ## A function


~~~c
void a_function(int foo);
~~~

